# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from iblai.models.heygen_marketing_video_detail import HeygenMarketingVideoDetail
from iblai.models.heygen_marketing_video_list import HeygenMarketingVideoList
from iblai.models.paginated_heygen_marketing_video_list_list import PaginatedHeygenMarketingVideoListList

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class AiMarketingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def ai_marketing_orgs_users_heygen_videos_create(
        self,
        org: StrictStr,
        user_id: StrictStr,
        heygen_marketing_video_list: Optional[HeygenMarketingVideoList] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_marketing_orgs_users_heygen_videos_create

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param heygen_marketing_video_list:
        :type heygen_marketing_video_list: HeygenMarketingVideoList
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_marketing_orgs_users_heygen_videos_create_serialize(
            org=org,
            user_id=user_id,
            heygen_marketing_video_list=heygen_marketing_video_list,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "HeygenMarketingVideoList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_marketing_orgs_users_heygen_videos_create_serialize(
        self,
        org,
        user_id,
        heygen_marketing_video_list,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if heygen_marketing_video_list is not None:
            _body_params = heygen_marketing_video_list


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_marketing_orgs_users_heygen_videos_list(
        self,
        org: StrictStr,
        user_id: StrictStr,
        page: Annotated[Optional[StrictInt], Field(description="A page number within the paginated result set.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_marketing_orgs_users_heygen_videos_list

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param page: A page number within the paginated result set.
        :type page: int
        :param page_size: Number of results to return per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_marketing_orgs_users_heygen_videos_list_serialize(
            org=org,
            user_id=user_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedHeygenMarketingVideoListList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_marketing_orgs_users_heygen_videos_list_serialize(
        self,
        org,
        user_id,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_marketing_orgs_users_heygen_videos_retrieve(
        self,
        name: StrictStr,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_marketing_orgs_users_heygen_videos_retrieve

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param name: (required)
        :type name: str
        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_marketing_orgs_users_heygen_videos_retrieve_serialize(
            name=name,
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "HeygenMarketingVideoDetail",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_marketing_orgs_users_heygen_videos_retrieve_serialize(
        self,
        name,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if name is not None:
            _path_params['name'] = name
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/{name}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.patched_rbac_group import PatchedRbacGroup

class TestPatchedRbacGroup(unittest.TestCase):
    """PatchedRbacGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedRbacGroup:
        """Test PatchedRbacGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedRbacGroup`
        """
        model = PatchedRbacGroup()
        if include_optional:
            return PatchedRbacGroup(
                id = 56,
                unique_id = '',
                platform = iblai.models.rbac_platform.RbacPlatform(
                    id = 56, 
                    key = '', 
                    name = '', ),
                platform_key = '',
                name = '',
                description = '',
                users = [
                    iblai.models.rbac_user.RbacUser(
                        id = 56, 
                        username = '', )
                    ],
                users_to_add = [
                    56
                    ],
                users_to_remove = [
                    56
                    ]
            )
        else:
            return PatchedRbacGroup(
        )
        """

    def testPatchedRbacGroup(self):
        """Test PatchedRbacGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.overtime_with_change_info import OvertimeWithChangeInfo

class TestOvertimeWithChangeInfo(unittest.TestCase):
    """OvertimeWithChangeInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OvertimeWithChangeInfo:
        """Test OvertimeWithChangeInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OvertimeWithChangeInfo`
        """
        model = OvertimeWithChangeInfo()
        if include_optional:
            return OvertimeWithChangeInfo(
                data = {
                    'key' : null
                    },
                total = 56,
                meta = iblai.models.overtime_meta.OvertimeMeta(
                    total = 56, 
                    change_range = 56, 
                    change_last_seven_days = 56, 
                    change_last_thirty_days = 56, 
                    change_last_seven_days_percent = 1.337, 
                    change_last_thirty_days_percent = 1.337, 
                    change_range_percent = 1.337, )
            )
        else:
            return OvertimeWithChangeInfo(
                meta = iblai.models.overtime_meta.OvertimeMeta(
                    total = 56, 
                    change_range = 56, 
                    change_last_seven_days = 56, 
                    change_last_thirty_days = 56, 
                    change_last_seven_days_percent = 1.337, 
                    change_last_thirty_days_percent = 1.337, 
                    change_range_percent = 1.337, ),
        )
        """

    def testOvertimeWithChangeInfo(self):
        """Test OvertimeWithChangeInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from .api_client import ApiClient
from .configuration import Configuration


def get_platform_api_client(host: str, key: str) -> ApiClient:
    """Return ApiClient configured to use an Platform Api Key token"""
    config = Configuration(
        host=host,
        api_key={"PlatformApiKeyAuthentication": key},
        api_key_prefix={"PlatformApiKeyAuthentication": "Api-Token"},
    )
    client = ApiClient(config)
    return client



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class PathwaySuggestionDetail(BaseModel):
    """
    Response serializer for pathway suggestion details
    """ # noqa: E501
    id: StrictInt = Field(description="The unique identifier for the suggestion")
    user_id: StrictInt = Field(description="The ID of the user receiving the suggestion")
    username: StrictStr = Field(description="The username of the user receiving the suggestion")
    name: StrictStr = Field(description="The full name of the user receiving the suggestion")
    platform_key: StrictStr = Field(description="The platform key associated with the suggestion")
    accepted: StrictBool = Field(description="Whether the suggestion has been accepted by the user")
    visible: StrictBool = Field(description="Whether the suggestion is visible to the user")
    created: datetime = Field(description="When the suggestion was created")
    modified: datetime = Field(description="When the suggestion was last modified")
    metadata: Dict[str, Any] = Field(description="Additional metadata for the suggestion")
    pathway_id: StrictStr = Field(description="The pathway ID being suggested")
    pathway_uuid: StrictStr = Field(description="The UUID of the pathway being suggested")
    pathway_name: StrictStr = Field(description="The name of the pathway being suggested")
    pathway_platform_key: StrictStr = Field(description="The platform key associated with the pathway")
    __properties: ClassVar[List[str]] = ["id", "user_id", "username", "name", "platform_key", "accepted", "visible", "created", "modified", "metadata", "pathway_id", "pathway_uuid", "pathway_name", "pathway_platform_key"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PathwaySuggestionDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PathwaySuggestionDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "name": obj.get("name"),
            "platform_key": obj.get("platform_key"),
            "accepted": obj.get("accepted"),
            "visible": obj.get("visible"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "metadata": obj.get("metadata"),
            "pathway_id": obj.get("pathway_id"),
            "pathway_uuid": obj.get("pathway_uuid"),
            "pathway_name": obj.get("pathway_name"),
            "pathway_platform_key": obj.get("pathway_platform_key")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.topic_model import TopicModel
from typing import Optional, Set
from typing_extensions import Self

class PatchedConversations(BaseModel):
    """
    PatchedConversations
    """ # noqa: E501
    id: Optional[StrictStr] = None
    messages: Optional[StrictStr] = None
    topics: Optional[List[TopicModel]] = None
    sentiment: Optional[StrictStr] = None
    mentor: Optional[StrictStr] = None
    student: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    model: Optional[StrictStr] = None
    rating: Optional[StrictInt] = None
    platform: Optional[StrictStr] = None
    lti_email: Optional[StrictStr] = Field(default=None, description="Email claim from LTI1.3 JWT if an LTI user and available")
    lti_username: Optional[StrictStr] = Field(default=None, description="Username claim from LTI1.3 JWT if an LTI user and available")
    inserted_at: Optional[datetime] = None
    has_document: Optional[StrictBool] = None
    memory_tracked: Optional[StrictBool] = None
    llm_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    llm_provider: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    metadata: Optional[Any] = None
    tools: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["id", "messages", "topics", "sentiment", "mentor", "student", "email", "model", "rating", "platform", "lti_email", "lti_username", "inserted_at", "has_document", "memory_tracked", "llm_name", "llm_provider", "metadata", "tools"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedConversations from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "messages",
            "sentiment",
            "student",
            "email",
            "rating",
            "lti_email",
            "lti_username",
            "inserted_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item in self.topics:
                if _item:
                    _items.append(_item.to_dict())
            _dict['topics'] = _items
        # set to None if llm_name (nullable) is None
        # and model_fields_set contains the field
        if self.llm_name is None and "llm_name" in self.model_fields_set:
            _dict['llm_name'] = None

        # set to None if llm_provider (nullable) is None
        # and model_fields_set contains the field
        if self.llm_provider is None and "llm_provider" in self.model_fields_set:
            _dict['llm_provider'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedConversations from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "messages": obj.get("messages"),
            "topics": [TopicModel.from_dict(_item) for _item in obj["topics"]] if obj.get("topics") is not None else None,
            "sentiment": obj.get("sentiment"),
            "mentor": obj.get("mentor"),
            "student": obj.get("student"),
            "email": obj.get("email"),
            "model": obj.get("model"),
            "rating": obj.get("rating"),
            "platform": obj.get("platform"),
            "lti_email": obj.get("lti_email"),
            "lti_username": obj.get("lti_username"),
            "inserted_at": obj.get("inserted_at"),
            "has_document": obj.get("has_document"),
            "memory_tracked": obj.get("memory_tracked"),
            "llm_name": obj.get("llm_name"),
            "llm_provider": obj.get("llm_provider"),
            "metadata": obj.get("metadata"),
            "tools": obj.get("tools")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.orgs_api import OrgsApi


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrgsApi()

    def tearDown(self) -> None:
        pass

    def test_orgs_scim_v2_department_members_create(self) -> None:
        """Test case for orgs_scim_v2_department_members_create

        """
        pass

    def test_orgs_scim_v2_department_members_destroy(self) -> None:
        """Test case for orgs_scim_v2_department_members_destroy

        """
        pass

    def test_orgs_scim_v2_department_members_retrieve(self) -> None:
        """Test case for orgs_scim_v2_department_members_retrieve

        """
        pass

    def test_orgs_scim_v2_department_members_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_department_members_retrieve2

        """
        pass

    def test_orgs_scim_v2_department_members_update(self) -> None:
        """Test case for orgs_scim_v2_department_members_update

        """
        pass

    def test_orgs_scim_v2_departments_add_members_create(self) -> None:
        """Test case for orgs_scim_v2_departments_add_members_create

        """
        pass

    def test_orgs_scim_v2_departments_create(self) -> None:
        """Test case for orgs_scim_v2_departments_create

        """
        pass

    def test_orgs_scim_v2_departments_destroy(self) -> None:
        """Test case for orgs_scim_v2_departments_destroy

        """
        pass

    def test_orgs_scim_v2_departments_remove_members_create(self) -> None:
        """Test case for orgs_scim_v2_departments_remove_members_create

        """
        pass

    def test_orgs_scim_v2_departments_retrieve(self) -> None:
        """Test case for orgs_scim_v2_departments_retrieve

        """
        pass

    def test_orgs_scim_v2_departments_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_departments_retrieve2

        """
        pass

    def test_orgs_scim_v2_departments_update(self) -> None:
        """Test case for orgs_scim_v2_departments_update

        """
        pass

    def test_orgs_scim_v2_group_members_create(self) -> None:
        """Test case for orgs_scim_v2_group_members_create

        """
        pass

    def test_orgs_scim_v2_group_members_destroy(self) -> None:
        """Test case for orgs_scim_v2_group_members_destroy

        """
        pass

    def test_orgs_scim_v2_group_members_retrieve(self) -> None:
        """Test case for orgs_scim_v2_group_members_retrieve

        """
        pass

    def test_orgs_scim_v2_group_members_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_group_members_retrieve2

        """
        pass

    def test_orgs_scim_v2_group_members_update(self) -> None:
        """Test case for orgs_scim_v2_group_members_update

        """
        pass

    def test_orgs_scim_v2_groups_add_members_create(self) -> None:
        """Test case for orgs_scim_v2_groups_add_members_create

        """
        pass

    def test_orgs_scim_v2_groups_create(self) -> None:
        """Test case for orgs_scim_v2_groups_create

        """
        pass

    def test_orgs_scim_v2_groups_destroy(self) -> None:
        """Test case for orgs_scim_v2_groups_destroy

        """
        pass

    def test_orgs_scim_v2_groups_remove_members_create(self) -> None:
        """Test case for orgs_scim_v2_groups_remove_members_create

        """
        pass

    def test_orgs_scim_v2_groups_retrieve(self) -> None:
        """Test case for orgs_scim_v2_groups_retrieve

        """
        pass

    def test_orgs_scim_v2_groups_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_groups_retrieve2

        """
        pass

    def test_orgs_scim_v2_groups_update(self) -> None:
        """Test case for orgs_scim_v2_groups_update

        """
        pass

    def test_orgs_scim_v2_users_create(self) -> None:
        """Test case for orgs_scim_v2_users_create

        """
        pass

    def test_orgs_scim_v2_users_destroy(self) -> None:
        """Test case for orgs_scim_v2_users_destroy

        """
        pass

    def test_orgs_scim_v2_users_retrieve(self) -> None:
        """Test case for orgs_scim_v2_users_retrieve

        """
        pass

    def test_orgs_scim_v2_users_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_users_retrieve2

        """
        pass

    def test_orgs_scim_v2_users_update(self) -> None:
        """Test case for orgs_scim_v2_users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_moderation_log_list import PaginatedModerationLogList

class TestPaginatedModerationLogList(unittest.TestCase):
    """PaginatedModerationLogList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedModerationLogList:
        """Test PaginatedModerationLogList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedModerationLogList`
        """
        model = PaginatedModerationLogList()
        if include_optional:
            return PaginatedModerationLogList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.moderation_log.ModerationLog(
                        id = 56, 
                        username = '', 
                        platform_key = '', 
                        mentor = 56, 
                        prompt = '', 
                        reason = '', 
                        target_system = 'Safety System', 
                        date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedModerationLogList(
        )
        """

    def testPaginatedModerationLogList(self):
        """Test PaginatedModerationLogList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.observation import Observation

class TestObservation(unittest.TestCase):
    """Observation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Observation:
        """Test Observation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Observation`
        """
        model = Observation()
        if include_optional:
            return Observation(
                id = '',
                trace_id = '',
                project_id = '',
                type = '',
                start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '',
                metadata = {
                    'key' : null
                    },
                parent_observation_id = '',
                level = '',
                status_message = '',
                version = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                model = '',
                model_parameters = {
                    'key' : null
                    },
                input = None,
                output = None,
                prompt_tokens = 56,
                completion_tokens = 56,
                total_tokens = 56,
                unit = '',
                completion_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                prompt_id = '',
                usage = {
                    'key' : null
                    },
                price = 1.337
            )
        else:
            return Observation(
                id = '',
                trace_id = '',
                project_id = '',
                type = '',
                start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '',
                metadata = {
                    'key' : null
                    },
                parent_observation_id = '',
                level = '',
                status_message = '',
                version = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                model = '',
                model_parameters = {
                    'key' : null
                    },
                input = None,
                output = None,
                prompt_tokens = 56,
                completion_tokens = 56,
                total_tokens = 56,
                unit = '',
                completion_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                prompt_id = '',
                price = 1.337,
        )
        """

    def testObservation(self):
        """Test Observation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.perlearner_grading_per_course_api import PerlearnerGradingPerCourseAPI

class TestPerlearnerGradingPerCourseAPI(unittest.TestCase):
    """PerlearnerGradingPerCourseAPI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerlearnerGradingPerCourseAPI:
        """Test PerlearnerGradingPerCourseAPI
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PerlearnerGradingPerCourseAPI`
        """
        model = PerlearnerGradingPerCourseAPI()
        if include_optional:
            return PerlearnerGradingPerCourseAPI(
                data = [
                    iblai.models.perlearner_grading_per_course_api_data.PerlearnerGradingPerCourseAPIData(
                        course_id = '', 
                        name = '', 
                        graded_activities = '', 
                        submissions = 56, 
                        problems_attempted = 56, 
                        assignments_correct = 56, 
                        class_average = 1.337, 
                        grade = 1.337, )
                    ]
            )
        else:
            return PerlearnerGradingPerCourseAPI(
                data = [
                    iblai.models.perlearner_grading_per_course_api_data.PerlearnerGradingPerCourseAPIData(
                        course_id = '', 
                        name = '', 
                        graded_activities = '', 
                        submissions = 56, 
                        problems_attempted = 56, 
                        assignments_correct = 56, 
                        class_average = 1.337, 
                        grade = 1.337, )
                    ],
        )
        """

    def testPerlearnerGradingPerCourseAPI(self):
        """Test PerlearnerGradingPerCourseAPI"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from iblai.models.campaign_enablement import CampaignEnablement
from iblai.models.campaign_exclusion import CampaignExclusion
from iblai.models.mark_all_read_request import MarkAllReadRequest
from iblai.models.mark_all_read_response import MarkAllReadResponse
from iblai.models.notification import Notification
from iblai.models.notification_count import NotificationCount
from iblai.models.notification_v1_campaigns_unsubscribe_retrieve200_response import NotificationV1CampaignsUnsubscribeRetrieve200Response
from iblai.models.patched_notification import PatchedNotification

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class NotificationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def notification_v1_campaigns_unsubscribe_retrieve(
        self,
        unsubscribe_hash: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_campaigns_unsubscribe_retrieve

        Unsubscribe from a campaign using a hash

        :param unsubscribe_hash: (required)
        :type unsubscribe_hash: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_campaigns_unsubscribe_retrieve_serialize(
            unsubscribe_hash=unsubscribe_hash,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "NotificationV1CampaignsUnsubscribeRetrieve200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_campaigns_unsubscribe_retrieve_serialize(
        self,
        unsubscribe_hash,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if unsubscribe_hash is not None:
            _path_params['unsubscribe_hash'] = unsubscribe_hash
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/notification/v1/campaigns/unsubscribe/{unsubscribe_hash}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_campaigns_enable_create(
        self,
        platform_key: StrictStr,
        campaign_enablement: Optional[CampaignEnablement] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_campaigns_enable_create

        Re-enable campaigns for a user

        :param platform_key: (required)
        :type platform_key: str
        :param campaign_enablement:
        :type campaign_enablement: CampaignEnablement
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_campaigns_enable_create_serialize(
            platform_key=platform_key,
            campaign_enablement=campaign_enablement,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "NotificationV1CampaignsUnsubscribeRetrieve200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_campaigns_enable_create_serialize(
        self,
        platform_key,
        campaign_enablement,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if platform_key is not None:
            _path_params['platform_key'] = platform_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if campaign_enablement is not None:
            _body_params = campaign_enablement


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/notification/v1/orgs/{platform_key}/campaigns/enable/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_campaigns_exclude_create(
        self,
        platform_key: StrictStr,
        campaign_exclusion: Optional[CampaignExclusion] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_campaigns_exclude_create

        Exclude a user from specified campaigns

        :param platform_key: (required)
        :type platform_key: str
        :param campaign_exclusion:
        :type campaign_exclusion: CampaignExclusion
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_campaigns_exclude_create_serialize(
            platform_key=platform_key,
            campaign_exclusion=campaign_exclusion,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "NotificationV1CampaignsUnsubscribeRetrieve200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_campaigns_exclude_create_serialize(
        self,
        platform_key,
        campaign_exclusion,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if platform_key is not None:
            _path_params['platform_key'] = platform_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if campaign_exclusion is not None:
            _body_params = campaign_exclusion


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/notification/v1/orgs/{platform_key}/campaigns/exclude/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_mark_all_as_read_create(
        self,
        platform_key: StrictStr,
        mark_all_read_request: Optional[MarkAllReadRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_mark_all_as_read_create

        Mark all notifications as read for a user. Optionally provide specific notification IDs.

        :param platform_key: (required)
        :type platform_key: str
        :param mark_all_read_request:
        :type mark_all_read_request: MarkAllReadRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_mark_all_as_read_create_serialize(
            platform_key=platform_key,
            mark_all_read_request=mark_all_read_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MarkAllReadResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_mark_all_as_read_create_serialize(
        self,
        platform_key,
        mark_all_read_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if platform_key is not None:
            _path_params['platform_key'] = platform_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if mark_all_read_request is not None:
            _body_params = mark_all_read_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/notification/v1/orgs/{platform_key}/mark-all-as-read',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_notifications_bulk_update_partial_update(
        self,
        org: StrictStr,
        patched_notification: Optional[PatchedNotification] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_notifications_bulk_update_partial_update

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param org: (required)
        :type org: str
        :param patched_notification:
        :type patched_notification: PatchedNotification
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_notifications_bulk_update_partial_update_serialize(
            org=org,
            patched_notification=patched_notification,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_notifications_bulk_update_partial_update_serialize(
        self,
        org,
        patched_notification,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_notification is not None:
            _body_params = patched_notification


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/notification/v1/orgs/{org}/notifications/bulk-update/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_notifications_retrieve(
        self,
        org: StrictStr,
        channel: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        end_date: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        exclude_channel: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        start_date: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        status: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_notifications_retrieve

        Get notifications for a user

        :param org: (required)
        :type org: str
        :param channel:
        :type channel: str
        :param end_date:
        :type end_date: str
        :param exclude_channel:
        :type exclude_channel: str
        :param start_date:
        :type start_date: str
        :param status:
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_notifications_retrieve_serialize(
            org=org,
            channel=channel,
            end_date=end_date,
            exclude_channel=exclude_channel,
            start_date=start_date,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_notifications_retrieve_serialize(
        self,
        org,
        channel,
        end_date,
        exclude_channel,
        start_date,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if channel is not None:
            
            _query_params.append(('channel', channel))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if exclude_channel is not None:
            
            _query_params.append(('exclude_channel', exclude_channel))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/notification/v1/orgs/{org}/notifications/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_notifications_update(
        self,
        org: StrictStr,
        notification: Notification,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_notifications_update

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param org: (required)
        :type org: str
        :param notification: (required)
        :type notification: Notification
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_notifications_update_serialize(
            org=org,
            notification=notification,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_notifications_update_serialize(
        self,
        org,
        notification,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if notification is not None:
            _body_params = notification


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/notification/v1/orgs/{org}/notifications/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_users_notifications_bulk_update_partial_update(
        self,
        org: StrictStr,
        user_id: StrictStr,
        patched_notification: Optional[PatchedNotification] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_users_notifications_bulk_update_partial_update

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param patched_notification:
        :type patched_notification: PatchedNotification
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_users_notifications_bulk_update_partial_update_serialize(
            org=org,
            user_id=user_id,
            patched_notification=patched_notification,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_users_notifications_bulk_update_partial_update_serialize(
        self,
        org,
        user_id,
        patched_notification,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_notification is not None:
            _body_params = patched_notification


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/notification/v1/orgs/{org}/users/{user_id}/notifications/bulk-update/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_users_notifications_count_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        channel: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        status: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_users_notifications_count_retrieve

        Get notifications count for a user

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param channel:
        :type channel: str
        :param status:
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_users_notifications_count_retrieve_serialize(
            org=org,
            user_id=user_id,
            channel=channel,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "NotificationCount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_users_notifications_count_retrieve_serialize(
        self,
        org,
        user_id,
        channel,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        if channel is not None:
            
            _query_params.append(('channel', channel))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/notification/v1/orgs/{org}/users/{user_id}/notifications-count/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_users_notifications_destroy(
        self,
        notification_id: StrictStr,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_users_notifications_destroy

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param notification_id: (required)
        :type notification_id: str
        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_users_notifications_destroy_serialize(
            notification_id=notification_id,
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_users_notifications_destroy_serialize(
        self,
        notification_id,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if notification_id is not None:
            _path_params['notification_id'] = notification_id
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/notification/v1/orgs/{org}/users/{user_id}/notifications/{notification_id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_users_notifications_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        channel: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        end_date: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        exclude_channel: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        start_date: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        status: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_users_notifications_retrieve

        Get notifications for a user

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param channel:
        :type channel: str
        :param end_date:
        :type end_date: str
        :param exclude_channel:
        :type exclude_channel: str
        :param start_date:
        :type start_date: str
        :param status:
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_users_notifications_retrieve_serialize(
            org=org,
            user_id=user_id,
            channel=channel,
            end_date=end_date,
            exclude_channel=exclude_channel,
            start_date=start_date,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_users_notifications_retrieve_serialize(
        self,
        org,
        user_id,
        channel,
        end_date,
        exclude_channel,
        start_date,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        if channel is not None:
            
            _query_params.append(('channel', channel))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if exclude_channel is not None:
            
            _query_params.append(('exclude_channel', exclude_channel))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/notification/v1/orgs/{org}/users/{user_id}/notifications/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def notification_v1_orgs_users_notifications_update(
        self,
        org: StrictStr,
        user_id: StrictStr,
        notification: Notification,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """notification_v1_orgs_users_notifications_update

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param notification: (required)
        :type notification: Notification
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._notification_v1_orgs_users_notifications_update_serialize(
            org=org,
            user_id=user_id,
            notification=notification,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Notification",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _notification_v1_orgs_users_notifications_update_serialize(
        self,
        org,
        user_id,
        notification,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if notification is not None:
            _body_params = notification


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/notification/v1/orgs/{org}/users/{user_id}/notifications/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_email_prompt_list_list import PaginatedEmailPromptListList

class TestPaginatedEmailPromptListList(unittest.TestCase):
    """PaginatedEmailPromptListList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedEmailPromptListList:
        """Test PaginatedEmailPromptListList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedEmailPromptListList`
        """
        model = PaginatedEmailPromptListList()
        if include_optional:
            return PaginatedEmailPromptListList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.email_prompt_list.EmailPromptList(
                        id = 56, 
                        sender_email = '', 
                        sender_name = '', 
                        subject = '', 
                        content_summary = '', 
                        mentor_name = '', 
                        mentor_email = '', 
                        is_processed = True, 
                        inserted_at = '', )
                    ]
            )
        else:
            return PaginatedEmailPromptListList(
                count = 123,
                results = [
                    iblai.models.email_prompt_list.EmailPromptList(
                        id = 56, 
                        sender_email = '', 
                        sender_name = '', 
                        subject = '', 
                        content_summary = '', 
                        mentor_name = '', 
                        mentor_email = '', 
                        is_processed = True, 
                        inserted_at = '', )
                    ],
        )
        """

    def testPaginatedEmailPromptListList(self):
        """Test PaginatedEmailPromptListList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.providers_api import ProvidersApi


class TestProvidersApi(unittest.TestCase):
    """ProvidersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProvidersApi()

    def tearDown(self) -> None:
        pass

    def test_providers_apple_associate_account_create(self) -> None:
        """Test case for providers_apple_associate_account_create

        """
        pass

    def test_providers_apple_hook_create(self) -> None:
        """Test case for providers_apple_hook_create

        """
        pass

    def test_providers_apple_subscription_status_create(self) -> None:
        """Test case for providers_apple_subscription_status_create

        """
        pass

    def test_providers_apple_validate_transaction_id_create(self) -> None:
        """Test case for providers_apple_validate_transaction_id_create

        """
        pass

    def test_providers_aws_create_organization_create(self) -> None:
        """Test case for providers_aws_create_organization_create

        """
        pass

    def test_providers_aws_domain_status_retrieve(self) -> None:
        """Test case for providers_aws_domain_status_retrieve

        """
        pass

    def test_providers_aws_launch_tenant_create(self) -> None:
        """Test case for providers_aws_launch_tenant_create

        """
        pass

    def test_providers_aws_sync_domain_records_create(self) -> None:
        """Test case for providers_aws_sync_domain_records_create

        """
        pass

    def test_providers_aws_sync_domain_records_retrieve(self) -> None:
        """Test case for providers_aws_sync_domain_records_retrieve

        """
        pass

    def test_providers_gcp_create_organization_create(self) -> None:
        """Test case for providers_gcp_create_organization_create

        """
        pass

    def test_providers_gcp_create_organization_create2(self) -> None:
        """Test case for providers_gcp_create_organization_create2

        """
        pass

    def test_providers_gcp_hook_create(self) -> None:
        """Test case for providers_gcp_hook_create

        """
        pass

    def test_providers_gcp_launch_tenant_create(self) -> None:
        """Test case for providers_gcp_launch_tenant_create

        """
        pass

    def test_providers_gcp_validate_signup_token_create(self) -> None:
        """Test case for providers_gcp_validate_signup_token_create

        """
        pass

    def test_providers_google_pay_get_account_retrieve(self) -> None:
        """Test case for providers_google_pay_get_account_retrieve

        """
        pass

    def test_providers_google_pay_hook_create(self) -> None:
        """Test case for providers_google_pay_hook_create

        """
        pass

    def test_providers_google_pay_validate_transaction_id_create(self) -> None:
        """Test case for providers_google_pay_validate_transaction_id_create

        """
        pass

    def test_providers_stripe_create_organization_create(self) -> None:
        """Test case for providers_stripe_create_organization_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.call_configuration import CallConfiguration
from iblai.models.greeting_method_enum import GreetingMethodEnum
from iblai.models.mcp_server import MCPServer
from iblai.models.mentor_category import MentorCategory
from typing import Optional, Set
from typing_extensions import Self

class Mentor(BaseModel):
    """
    Mentor
    """ # noqa: E501
    name: Annotated[str, Field(strict=True, max_length=255)]
    unique_id: Optional[StrictStr] = None
    flow: Optional[Any] = Field(description="The langflow json for the mentor")
    slug: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    platform: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    allow_anonymous: Optional[StrictBool] = None
    metadata: Optional[Any] = None
    enable_moderation: Optional[StrictBool] = None
    enable_post_processing_system: Optional[StrictBool] = None
    enable_openai_assistant: Optional[StrictBool] = Field(default=None, description="(Deprecated) Set template mentor to openai-agent instead.")
    enable_total_grounding: Optional[StrictBool] = Field(default=None, description="Whether to force mentor to only use information within the provided documents.")
    enable_suggested_prompts: Optional[StrictBool] = Field(default=None, description="Whether to show suggested prompts for the mentor or not. Note: Suggested prompts are created by tenant admins.")
    enable_guided_prompts: Optional[StrictBool] = Field(default=None, description="Whether to show suggested prompts for the mentor or not. Note: Guided prompts are created with an llm based on chat history.")
    guided_prompt_instructions: Optional[StrictStr] = Field(default=None, description="Instructions to determine how prompt suggestions are generated.")
    google_voice: Optional[StrictInt] = None
    openai_voice: Optional[StrictInt] = None
    categories: List[MentorCategory]
    proactive_prompt: Optional[StrictStr] = Field(default=None, description="Prompt template used to start a conversation with the user when greeting_type is proactive_prompt. This will be sent to the LLM so it can respond naturally")
    moderation_system_prompt: Optional[StrictStr] = Field(default=None, description="The prompt for the moderation system. This prompt must clearly distinguish between 'Approapriate' and 'Not Appropriate' queries.")
    post_processing_prompt: Optional[StrictStr] = Field(default=None, description="Prompt to be used to alter or modify final llm response into any desired form.")
    moderation_response: Optional[StrictStr] = Field(default=None, description="Desired feedback to return to the user when their prompt is deemed inappropriate.")
    safety_system_prompt: Optional[StrictStr] = Field(default=None, description="Prompt to check whether the models response is appropriate or not.")
    safety_response: Optional[StrictStr] = Field(default=None, description="Feedback given to the user when a model generates an inappropriate response")
    enable_safety_system: Optional[StrictBool] = None
    proactive_response: Optional[StrictStr] = Field(default=None, description="Response to start a conversation with a user.")
    greeting_method: Optional[GreetingMethodEnum] = Field(default=None, description="How the mentor should greet the user. proactive_prompt: Allow the LLM to respond to proactive_prompt msg. proactive_response: use proactive_response template without performing an LLM call.  * `proactive_prompt` - Proactive Prompt * `proactive_response` - Proactive Response")
    call_configuration: Optional[CallConfiguration] = None
    mcp_servers: List[MCPServer]
    last_accessed_by: Optional[StrictInt] = Field(default=None, description="edX user ID")
    recently_accessed_at: Optional[datetime] = None
    created_by: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    created_at: Optional[datetime]
    updated_at: Optional[datetime]
    __properties: ClassVar[List[str]] = ["name", "unique_id", "flow", "slug", "platform", "allow_anonymous", "metadata", "enable_moderation", "enable_post_processing_system", "enable_openai_assistant", "enable_total_grounding", "enable_suggested_prompts", "enable_guided_prompts", "guided_prompt_instructions", "google_voice", "openai_voice", "categories", "proactive_prompt", "moderation_system_prompt", "post_processing_prompt", "moderation_response", "safety_system_prompt", "safety_response", "enable_safety_system", "proactive_response", "greeting_method", "call_configuration", "mcp_servers", "last_accessed_by", "recently_accessed_at", "created_by", "created_at", "updated_at"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Mentor from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "created_at",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item in self.categories:
                if _item:
                    _items.append(_item.to_dict())
            _dict['categories'] = _items
        # override the default output from pydantic by calling `to_dict()` of call_configuration
        if self.call_configuration:
            _dict['call_configuration'] = self.call_configuration.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in mcp_servers (list)
        _items = []
        if self.mcp_servers:
            for _item in self.mcp_servers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mcp_servers'] = _items
        # set to None if flow (nullable) is None
        # and model_fields_set contains the field
        if self.flow is None and "flow" in self.model_fields_set:
            _dict['flow'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if google_voice (nullable) is None
        # and model_fields_set contains the field
        if self.google_voice is None and "google_voice" in self.model_fields_set:
            _dict['google_voice'] = None

        # set to None if openai_voice (nullable) is None
        # and model_fields_set contains the field
        if self.openai_voice is None and "openai_voice" in self.model_fields_set:
            _dict['openai_voice'] = None

        # set to None if last_accessed_by (nullable) is None
        # and model_fields_set contains the field
        if self.last_accessed_by is None and "last_accessed_by" in self.model_fields_set:
            _dict['last_accessed_by'] = None

        # set to None if recently_accessed_at (nullable) is None
        # and model_fields_set contains the field
        if self.recently_accessed_at is None and "recently_accessed_at" in self.model_fields_set:
            _dict['recently_accessed_at'] = None

        # set to None if created_by (nullable) is None
        # and model_fields_set contains the field
        if self.created_by is None and "created_by" in self.model_fields_set:
            _dict['created_by'] = None

        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict['created_at'] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict['updated_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Mentor from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "unique_id": obj.get("unique_id"),
            "flow": obj.get("flow"),
            "slug": obj.get("slug"),
            "platform": obj.get("platform"),
            "allow_anonymous": obj.get("allow_anonymous"),
            "metadata": obj.get("metadata"),
            "enable_moderation": obj.get("enable_moderation"),
            "enable_post_processing_system": obj.get("enable_post_processing_system"),
            "enable_openai_assistant": obj.get("enable_openai_assistant"),
            "enable_total_grounding": obj.get("enable_total_grounding"),
            "enable_suggested_prompts": obj.get("enable_suggested_prompts"),
            "enable_guided_prompts": obj.get("enable_guided_prompts"),
            "guided_prompt_instructions": obj.get("guided_prompt_instructions"),
            "google_voice": obj.get("google_voice"),
            "openai_voice": obj.get("openai_voice"),
            "categories": [MentorCategory.from_dict(_item) for _item in obj["categories"]] if obj.get("categories") is not None else None,
            "proactive_prompt": obj.get("proactive_prompt"),
            "moderation_system_prompt": obj.get("moderation_system_prompt"),
            "post_processing_prompt": obj.get("post_processing_prompt"),
            "moderation_response": obj.get("moderation_response"),
            "safety_system_prompt": obj.get("safety_system_prompt"),
            "safety_response": obj.get("safety_response"),
            "enable_safety_system": obj.get("enable_safety_system"),
            "proactive_response": obj.get("proactive_response"),
            "greeting_method": obj.get("greeting_method"),
            "call_configuration": CallConfiguration.from_dict(obj["call_configuration"]) if obj.get("call_configuration") is not None else None,
            "mcp_servers": [MCPServer.from_dict(_item) for _item in obj["mcp_servers"]] if obj.get("mcp_servers") is not None else None,
            "last_accessed_by": obj.get("last_accessed_by"),
            "recently_accessed_at": obj.get("recently_accessed_at"),
            "created_by": obj.get("created_by"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TeamsWebhook(BaseModel):
    """
    TeamsWebhook
    """ # noqa: E501
    id: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    channel_data: Optional[Dict[str, Any]] = Field(default=None, alias="channelData")
    entities: Optional[List[Any]] = None
    text: Optional[StrictStr] = None
    locale: Optional[StrictStr] = None
    text_format: Optional[StrictStr] = Field(default=None, alias="textFormat")
    recipient: Optional[Dict[str, Any]] = None
    conversation: Optional[Dict[str, Any]] = None
    from_: Optional[Dict[str, Any]] = None
    channel_id: Optional[StrictStr] = Field(default=None, alias="channelId")
    service_url: Optional[StrictStr] = Field(default=None, alias="serviceUrl")
    local_timezone: Optional[StrictStr] = Field(default=None, alias="localTimezone")
    local_timestamp: Optional[StrictStr] = Field(default=None, alias="localTimestamp")
    timestamp: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "type", "channelData", "entities", "text", "locale", "textFormat", "recipient", "conversation", "from_", "channelId", "serviceUrl", "localTimezone", "localTimestamp", "timestamp"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TeamsWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if channel_data (nullable) is None
        # and model_fields_set contains the field
        if self.channel_data is None and "channel_data" in self.model_fields_set:
            _dict['channelData'] = None

        # set to None if entities (nullable) is None
        # and model_fields_set contains the field
        if self.entities is None and "entities" in self.model_fields_set:
            _dict['entities'] = None

        # set to None if text (nullable) is None
        # and model_fields_set contains the field
        if self.text is None and "text" in self.model_fields_set:
            _dict['text'] = None

        # set to None if locale (nullable) is None
        # and model_fields_set contains the field
        if self.locale is None and "locale" in self.model_fields_set:
            _dict['locale'] = None

        # set to None if text_format (nullable) is None
        # and model_fields_set contains the field
        if self.text_format is None and "text_format" in self.model_fields_set:
            _dict['textFormat'] = None

        # set to None if recipient (nullable) is None
        # and model_fields_set contains the field
        if self.recipient is None and "recipient" in self.model_fields_set:
            _dict['recipient'] = None

        # set to None if conversation (nullable) is None
        # and model_fields_set contains the field
        if self.conversation is None and "conversation" in self.model_fields_set:
            _dict['conversation'] = None

        # set to None if from_ (nullable) is None
        # and model_fields_set contains the field
        if self.from_ is None and "from_" in self.model_fields_set:
            _dict['from_'] = None

        # set to None if channel_id (nullable) is None
        # and model_fields_set contains the field
        if self.channel_id is None and "channel_id" in self.model_fields_set:
            _dict['channelId'] = None

        # set to None if service_url (nullable) is None
        # and model_fields_set contains the field
        if self.service_url is None and "service_url" in self.model_fields_set:
            _dict['serviceUrl'] = None

        # set to None if local_timezone (nullable) is None
        # and model_fields_set contains the field
        if self.local_timezone is None and "local_timezone" in self.model_fields_set:
            _dict['localTimezone'] = None

        # set to None if local_timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.local_timestamp is None and "local_timestamp" in self.model_fields_set:
            _dict['localTimestamp'] = None

        # set to None if timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.timestamp is None and "timestamp" in self.model_fields_set:
            _dict['timestamp'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TeamsWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "channelData": obj.get("channelData"),
            "entities": obj.get("entities"),
            "text": obj.get("text"),
            "locale": obj.get("locale"),
            "textFormat": obj.get("textFormat"),
            "recipient": obj.get("recipient"),
            "conversation": obj.get("conversation"),
            "from_": obj.get("from_"),
            "channelId": obj.get("channelId"),
            "serviceUrl": obj.get("serviceUrl"),
            "localTimezone": obj.get("localTimezone"),
            "localTimestamp": obj.get("localTimestamp"),
            "timestamp": obj.get("timestamp")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_create import MentorCreate

class TestMentorCreate(unittest.TestCase):
    """MentorCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorCreate:
        """Test MentorCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorCreate`
        """
        model = MentorCreate()
        if include_optional:
            return MentorCreate(
                name = '',
                unique_id = '',
                flow = None,
                slug = 'z',
                platform = '',
                allow_anonymous = True,
                metadata = None,
                enable_moderation = True,
                enable_post_processing_system = True,
                enable_openai_assistant = True,
                enable_total_grounding = True,
                enable_suggested_prompts = True,
                enable_guided_prompts = True,
                google_voice = 56,
                openai_voice = 56,
                guided_prompt_instructions = '',
                categories = [
                    56
                    ],
                proactive_prompt = '',
                moderation_system_prompt = '',
                post_processing_prompt = '',
                moderation_response = '',
                safety_system_prompt = '',
                safety_response = '',
                disable_chathistory = True,
                enable_safety_system = True,
                proactive_response = '',
                mcp_servers = [
                    56
                    ],
                greeting_method = 'proactive_prompt',
                last_accessed_by = 56,
                recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MentorCreate(
                name = '',
                flow = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testMentorCreate(self):
        """Test MentorCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_course_license_group_assignment import PaginatedCourseLicenseGroupAssignment

class TestPaginatedCourseLicenseGroupAssignment(unittest.TestCase):
    """PaginatedCourseLicenseGroupAssignment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedCourseLicenseGroupAssignment:
        """Test PaginatedCourseLicenseGroupAssignment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedCourseLicenseGroupAssignment`
        """
        model = PaginatedCourseLicenseGroupAssignment()
        if include_optional:
            return PaginatedCourseLicenseGroupAssignment(
                count = 56,
                next_page = '',
                previous_page = '',
                results = [
                    iblai.models.course_license_group_assignment_detail.CourseLicenseGroupAssignmentDetail(
                        id = 56, 
                        group_id = 56, 
                        group_name = '', 
                        active = True, 
                        fulfilled = True, 
                        redirect_to = '', 
                        metadata = {
                            'key' : null
                            }, 
                        license_id = 56, 
                        license_name = '', 
                        course_id = '', )
                    ]
            )
        else:
            return PaginatedCourseLicenseGroupAssignment(
                count = 56,
                next_page = '',
                previous_page = '',
                results = [
                    iblai.models.course_license_group_assignment_detail.CourseLicenseGroupAssignmentDetail(
                        id = 56, 
                        group_id = 56, 
                        group_name = '', 
                        active = True, 
                        fulfilled = True, 
                        redirect_to = '', 
                        metadata = {
                            'key' : null
                            }, 
                        license_id = 56, 
                        license_name = '', 
                        course_id = '', )
                    ],
        )
        """

    def testPaginatedCourseLicenseGroupAssignment(self):
        """Test PaginatedCourseLicenseGroupAssignment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_settings_request import MentorSettingsRequest

class TestMentorSettingsRequest(unittest.TestCase):
    """MentorSettingsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorSettingsRequest:
        """Test MentorSettingsRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorSettingsRequest`
        """
        model = MentorSettingsRequest()
        if include_optional:
            return MentorSettingsRequest(
                mentor_name = '',
                display_name = '',
                profile_image = '',
                initial_message = '',
                suggested_message = '',
                theme = '',
                user_message_color = '',
                mentor_bubble_color = '',
                align_mentor_bubble = '',
                system_prompt = '',
                llm_provider = '',
                llm_name = '',
                featured = True,
                metadata = None,
                custom_css = '',
                mentor_visibility = '',
                enable_image_generation = True,
                enable_web_browsing = True,
                enable_code_interpreter = True,
                allow_anonymous = True,
                mentor_description = '',
                uploaded_profile_image = '',
                proactive_message = '',
                can_use_tools = True,
                tool_slugs = [
                    ''
                    ],
                llm_temperature = 0.0,
                proactive_prompt = '',
                moderation_system_prompt = '',
                moderation_response = '',
                enable_moderation = True,
                safety_system_prompt = '',
                safety_response = '',
                enable_safety_system = True
            )
        else:
            return MentorSettingsRequest(
        )
        """

    def testMentorSettingsRequest(self):
        """Test MentorSettingsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_training_list import PaginatedTrainingList

class TestPaginatedTrainingList(unittest.TestCase):
    """PaginatedTrainingList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedTrainingList:
        """Test PaginatedTrainingList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedTrainingList`
        """
        model = PaginatedTrainingList()
        if include_optional:
            return PaginatedTrainingList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.training.Training(
                        id = '', 
                        dataset = iblai.models.data_set.DataSet(
                            id = '', 
                            platform = {
                                'key' : null
                                }, 
                            name = '', 
                            prompt = '', 
                            source_url = '', 
                            source_file = '', 
                            status = 'pending', 
                            num_data_points = 56, 
                            train_split = 0, 
                            train_file = '', 
                            test_file = '', 
                            retry_attempts = 56, 
                            error_log = '', 
                            date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        project_name = '', 
                        metadata = null, 
                        status = 'trained', 
                        retry_attempts = 56, 
                        fine_tuned_model = '', 
                        provider = 'openai', 
                        base_model_name = '', 
                        text_column = '', 
                        learning_rate = 1.337, 
                        batch_size = 56, 
                        num_epochs = 56, 
                        block_size = 56, 
                        warmup_ratio = 1.337, 
                        lora_r = 56, 
                        lora_alpha = 56, 
                        lora_dropout = 1.337, 
                        weight_decay = 1.337, 
                        gradient_accumulation = 56, 
                        use_peft = True, 
                        use_fp16 = True, 
                        use_int4 = True, 
                        push_to_hub = True, 
                        repo_id = '', 
                        preprocess_dataset = True, 
                        prompt_column = '', 
                        response_column = '', 
                        prompt_prefix = '', 
                        prompt_suffix = '', 
                        response_prefix = '', 
                        response_suffix = '', 
                        error_log = '', 
                        date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        platform = 56, )
                    ]
            )
        else:
            return PaginatedTrainingList(
        )
        """

    def testPaginatedTrainingList(self):
        """Test PaginatedTrainingList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_periodic_agent_list import PaginatedPeriodicAgentList

class TestPaginatedPeriodicAgentList(unittest.TestCase):
    """PaginatedPeriodicAgentList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedPeriodicAgentList:
        """Test PaginatedPeriodicAgentList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedPeriodicAgentList`
        """
        model = PaginatedPeriodicAgentList()
        if include_optional:
            return PaginatedPeriodicAgentList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.periodic_agent.PeriodicAgent(
                        id = 56, 
                        mentor = iblai.models.mentor.Mentor(
                            name = '', 
                            unique_id = '', 
                            flow = null, 
                            slug = 'z', 
                            platform = '', 
                            allow_anonymous = True, 
                            metadata = null, 
                            enable_moderation = True, 
                            is_proactive = True, 
                            proactive_prompt = '', 
                            moderation_system_prompt = '', 
                            moderation_response = '', 
                            safety_system_prompt = '', 
                            safety_response = '', 
                            enable_safety_system = True, 
                            proactive_message = '', 
                            created_by = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        title = '', 
                        username = '', 
                        description = '', 
                        prompt = '', 
                        task = iblai.models.periodic_task.PeriodicTask(
                            id = 56, 
                            name = '', 
                            crontab = iblai.models.crontab_schedule.CrontabSchedule(
                                minute = '', 
                                hour = '', 
                                day_of_week = '', 
                                day_of_month = '', 
                                month_of_year = '', ), 
                            one_off = True, 
                            start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            enabled = True, ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        enabled = True, 
                        one_off = '', 
                        platform_key = '', 
                        pathway = '', 
                        callback_url = '', 
                        callback_secret = '', 
                        parent_session_id = '', 
                        parent_mentor_id = 56, 
                        previous_agent = 56, 
                        previous_agent_status = null, 
                        previous_agent_output = '', )
                    ]
            )
        else:
            return PaginatedPeriodicAgentList(
        )
        """

    def testPaginatedPeriodicAgentList(self):
        """Test PaginatedPeriodicAgentList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.web_resource import WebResource

class TestWebResource(unittest.TestCase):
    """WebResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebResource:
        """Test WebResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebResource`
        """
        model = WebResource()
        if include_optional:
            return WebResource(
                content = '',
                title = '',
                image_url = '',
                source = '',
                metadata = None,
                card = iblai.models.web_resource_card.WebResourceCard(
                    title = '', 
                    description = '', 
                    image_url = '', 
                    domain = '', 
                    site_name = '', )
            )
        else:
            return WebResource(
                content = '',
                title = '',
        )
        """

    def testWebResource(self):
        """Test WebResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_search_response import MentorSearchResponse

class TestMentorSearchResponse(unittest.TestCase):
    """MentorSearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorSearchResponse:
        """Test MentorSearchResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorSearchResponse`
        """
        model = MentorSearchResponse()
        if include_optional:
            return MentorSearchResponse(
                results = [
                    iblai.models.mentor.Mentor(
                        name = '', 
                        unique_id = '', 
                        flow = null, 
                        slug = 'z', 
                        platform = '', 
                        allow_anonymous = True, 
                        metadata = null, 
                        enable_moderation = True, 
                        enable_post_processing_system = True, 
                        enable_openai_assistant = True, 
                        enable_total_grounding = True, 
                        enable_suggested_prompts = True, 
                        enable_guided_prompts = True, 
                        guided_prompt_instructions = '', 
                        google_voice = 56, 
                        openai_voice = 56, 
                        categories = [
                            iblai.models.mentor_category.MentorCategory(
                                id = 56, 
                                name = '', 
                                description = '', 
                                category_group = 56, 
                                audience = iblai.models.mentor_audience.MentorAudience(
                                    id = 56, 
                                    name = '', 
                                    description = '', ), 
                                audiences = [
                                    iblai.models.mentor_audience.MentorAudience(
                                        id = 56, 
                                        name = '', 
                                        description = '', )
                                    ], )
                            ], 
                        proactive_prompt = '', 
                        moderation_system_prompt = '', 
                        post_processing_prompt = '', 
                        moderation_response = '', 
                        safety_system_prompt = '', 
                        safety_response = '', 
                        enable_safety_system = True, 
                        proactive_response = '', 
                        greeting_method = null, 
                        call_configuration = iblai.models.call_configuration.CallConfiguration(
                            id = 56, 
                            mentor = 56, 
                            mode = 'realtime', 
                            tts_provider = 'openai', 
                            stt_provider = 'openai', 
                            llm_provider = 'openai', 
                            use_function_calling_for_rag = True, 
                            google_voice = iblai.models.voice.Voice(
                                id = 56, 
                                name = '', 
                                provider = 'openai', 
                                language = '', 
                                description = '', 
                                audio_url = '', ), 
                            openai_voice = iblai.models.voice.Voice(
                                id = 56, 
                                name = '', 
                                provider = 'openai', 
                                language = '', 
                                description = '', 
                                audio_url = '', ), 
                            openai_voice_id = 56, 
                            google_voice_id = 56, 
                            enable_video = True, 
                            platform_key = '', ), 
                        mcp_servers = [
                            iblai.models.mcp_server.MCPServer(
                                id = 56, 
                                platform = 56, 
                                name = '', 
                                url = '', 
                                transport = 'sse', 
                                headers = null, 
                                platform_key = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        last_accessed_by = 56, 
                        recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                count = 56,
                next = '',
                previous = '',
                current_page = 56,
                total_pages = 56,
                facets = {
                    'key' : iblai.models.mentor_facet.MentorFacet(
                        total = 56, 
                        terms = {
                            'key' : null
                            }, 
                        other = 56, )
                    }
            )
        else:
            return MentorSearchResponse(
                results = [
                    iblai.models.mentor.Mentor(
                        name = '', 
                        unique_id = '', 
                        flow = null, 
                        slug = 'z', 
                        platform = '', 
                        allow_anonymous = True, 
                        metadata = null, 
                        enable_moderation = True, 
                        enable_post_processing_system = True, 
                        enable_openai_assistant = True, 
                        enable_total_grounding = True, 
                        enable_suggested_prompts = True, 
                        enable_guided_prompts = True, 
                        guided_prompt_instructions = '', 
                        google_voice = 56, 
                        openai_voice = 56, 
                        categories = [
                            iblai.models.mentor_category.MentorCategory(
                                id = 56, 
                                name = '', 
                                description = '', 
                                category_group = 56, 
                                audience = iblai.models.mentor_audience.MentorAudience(
                                    id = 56, 
                                    name = '', 
                                    description = '', ), 
                                audiences = [
                                    iblai.models.mentor_audience.MentorAudience(
                                        id = 56, 
                                        name = '', 
                                        description = '', )
                                    ], )
                            ], 
                        proactive_prompt = '', 
                        moderation_system_prompt = '', 
                        post_processing_prompt = '', 
                        moderation_response = '', 
                        safety_system_prompt = '', 
                        safety_response = '', 
                        enable_safety_system = True, 
                        proactive_response = '', 
                        greeting_method = null, 
                        call_configuration = iblai.models.call_configuration.CallConfiguration(
                            id = 56, 
                            mentor = 56, 
                            mode = 'realtime', 
                            tts_provider = 'openai', 
                            stt_provider = 'openai', 
                            llm_provider = 'openai', 
                            use_function_calling_for_rag = True, 
                            google_voice = iblai.models.voice.Voice(
                                id = 56, 
                                name = '', 
                                provider = 'openai', 
                                language = '', 
                                description = '', 
                                audio_url = '', ), 
                            openai_voice = iblai.models.voice.Voice(
                                id = 56, 
                                name = '', 
                                provider = 'openai', 
                                language = '', 
                                description = '', 
                                audio_url = '', ), 
                            openai_voice_id = 56, 
                            google_voice_id = 56, 
                            enable_video = True, 
                            platform_key = '', ), 
                        mcp_servers = [
                            iblai.models.mcp_server.MCPServer(
                                id = 56, 
                                platform = 56, 
                                name = '', 
                                url = '', 
                                transport = 'sse', 
                                headers = null, 
                                platform_key = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        last_accessed_by = 56, 
                        recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                count = 56,
                next = '',
                previous = '',
                current_page = 56,
                total_pages = 56,
        )
        """

    def testMentorSearchResponse(self):
        """Test MentorSearchResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from iblai.models.provider63a_enum import Provider63aEnum
from typing import Optional, Set
from typing_extensions import Self

class PatchedTrainingCreate(BaseModel):
    """
    PatchedTrainingCreate
    """ # noqa: E501
    id: Optional[StrictStr] = None
    project_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    dataset: Optional[StrictStr] = None
    base_model_name: Optional[Annotated[str, Field(strict=True, max_length=400)]] = None
    provider: Optional[Provider63aEnum] = None
    text_column: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    learning_rate: Optional[Union[StrictFloat, StrictInt]] = None
    batch_size: Optional[StrictInt] = None
    num_epochs: Optional[StrictInt] = None
    block_size: Optional[StrictInt] = None
    warmup_ratio: Optional[Union[StrictFloat, StrictInt]] = None
    lora_r: Optional[StrictInt] = None
    lora_alpha: Optional[StrictInt] = None
    lora_dropout: Optional[Union[StrictFloat, StrictInt]] = None
    weight_decay: Optional[Union[StrictFloat, StrictInt]] = None
    gradient_accumulation: Optional[StrictInt] = None
    use_peft: Optional[StrictBool] = None
    use_fp16: Optional[StrictBool] = None
    use_int4: Optional[StrictBool] = None
    push_to_hub: Optional[StrictBool] = None
    repo_id: Optional[Annotated[str, Field(strict=True, max_length=400)]] = None
    preprocess_dataset: Optional[StrictBool] = None
    prompt_column: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    prompt_prefix: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    prompt_suffix: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    response_prefix: Optional[Annotated[str, Field(strict=True, max_length=50)]] = None
    date_created: Optional[datetime] = None
    last_modified: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["id", "project_name", "dataset", "base_model_name", "provider", "text_column", "learning_rate", "batch_size", "num_epochs", "block_size", "warmup_ratio", "lora_r", "lora_alpha", "lora_dropout", "weight_decay", "gradient_accumulation", "use_peft", "use_fp16", "use_int4", "push_to_hub", "repo_id", "preprocess_dataset", "prompt_column", "prompt_prefix", "prompt_suffix", "response_prefix", "date_created", "last_modified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedTrainingCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "date_created",
            "last_modified",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedTrainingCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "project_name": obj.get("project_name"),
            "dataset": obj.get("dataset"),
            "base_model_name": obj.get("base_model_name"),
            "provider": obj.get("provider"),
            "text_column": obj.get("text_column"),
            "learning_rate": obj.get("learning_rate"),
            "batch_size": obj.get("batch_size"),
            "num_epochs": obj.get("num_epochs"),
            "block_size": obj.get("block_size"),
            "warmup_ratio": obj.get("warmup_ratio"),
            "lora_r": obj.get("lora_r"),
            "lora_alpha": obj.get("lora_alpha"),
            "lora_dropout": obj.get("lora_dropout"),
            "weight_decay": obj.get("weight_decay"),
            "gradient_accumulation": obj.get("gradient_accumulation"),
            "use_peft": obj.get("use_peft"),
            "use_fp16": obj.get("use_fp16"),
            "use_int4": obj.get("use_int4"),
            "push_to_hub": obj.get("push_to_hub"),
            "repo_id": obj.get("repo_id"),
            "preprocess_dataset": obj.get("preprocess_dataset"),
            "prompt_column": obj.get("prompt_column"),
            "prompt_prefix": obj.get("prompt_prefix"),
            "prompt_suffix": obj.get("prompt_suffix"),
            "response_prefix": obj.get("response_prefix"),
            "date_created": obj.get("date_created"),
            "last_modified": obj.get("last_modified")
        })
        return _obj


